/*
 https://github.com/gaearon/redux/blob/breaking-changes-1.0/src/utils/compose.js
 */
/**
 * Composes functions from left to right.
 *
 * @param {...Function} funcs - The functions to compose.
 * @returns {Function} A function that passes its only argument to the first of
 * the `funcs`, then pipes its return value to the second one, and so on, until
 * the last of the `funcs` is called, and its result is returned.
 */
"use strict";

exports.__esModule = true;
exports["default"] = compose;

function compose() {
  for (var _len = arguments.length, funcs = Array(_len), _key = 0; _key < _len; _key++) {
    funcs[_key] = arguments[_key];
  }

  return funcs.reduceRight(function (composed, f) {
    return f(composed);
  });
}

module.exports = exports["default"];