/*
 https://github.com/gaearon/redux/blob/breaking-changes-1.0/src/utils/isPlainObject.js
 */

'use strict';

exports.__esModule = true;
exports['default'] = isPlainObject;
function fnToString(fn) {
  return Function.prototype.toString.call(fn);
}

/**
 * @param {any} obj The object to inspect.
 * @returns {boolean} True if the argument appears to be a plain object.
 */

function isPlainObject(obj) {
  if (!obj || typeof obj !== 'object') {
    return false;
  }

  var proto = typeof obj.constructor === 'function' ? Object.getPrototypeOf(obj) : Object.prototype;

  if (proto === null) {
    return true;
  }

  var constructor = proto.constructor;

  return typeof constructor === 'function' && constructor instanceof constructor && fnToString(constructor) === fnToString(Object);
}

module.exports = exports['default'];